/*
 * Author: Richard Lord
 * Copyright (c) Richard Lord 2010
 * http://www.richardlord.net
 * 
 * Licence Agreement
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.richardlord.smartcomponents.twitter.context
{
	import net.richardlord.smartcomponents.twitter.buttons.SearchButton;
	import net.richardlord.smartcomponents.twitter.buttons.ToggleSearchButton;
	import net.richardlord.smartcomponents.twitter.data.TweetCollection;
	import net.richardlord.smartcomponents.twitter.data.User;
	import net.richardlord.smartcomponents.twitter.managers.*;
	import net.richardlord.smartcomponents.twitter.services.*;
	import net.richardlord.smartcomponents.twitter.services.parsers.*;
	import net.richardlord.smartcomponents.twitter.services.tools.TwitterRequest;
	
	import org.flaircode.oauth.IOAuth;
	import org.flaircode.oauth.OAuth;
	import org.robotlegs.mvcs.Context;
	
	public class TwitterContext extends Context
	{
		[Inspectable( defaultValue="", category="Common" )]
		public var oauthConsumerKey : String;
		
		[Inspectable( defaultValue="", category="Common" )]
		public var oauthConsumerSecret : String;
		
		override public function startup():void
		{
			injector.mapSingleton( TweetCollection );
			injector.mapSingleton( User );
			injector.mapSingleton( AuthenticateManager );
			injector.mapValue( IOAuth, new OAuth( oauthConsumerKey, oauthConsumerSecret ) );
			
			injector.mapClass( HomeManager, HomeManager );
			injector.mapClass( MoreManager, MoreManager );
			injector.mapClass( RefreshManager, RefreshManager );
			injector.mapClass( SearchManager, SearchManager );
			injector.mapClass( TweetManager, TweetManager );
			
			injector.mapClass( HomeService, HomeService );
			injector.mapClass( MoreService, MoreService );
			injector.mapClass( RefreshService, RefreshService );
			injector.mapClass( SearchService, SearchService );
			injector.mapClass( TweetService, TweetService );

			injector.mapClass( TwitterRequest, TwitterRequest );
			injector.mapClass( SearchParser, SearchParser );
			injector.mapClass( TimelineAtomParser, TimelineAtomParser );
			injector.mapClass( TweetXmlParser, TweetXmlParser );

			viewMap.mapPackage( "net.richardlord.smartcomponents.twitter" );
		}
	}
}